@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use Carp::SyntaxHighlightSource;
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 our %options;
 
@@ -48,19 +48,21 @@ END {
 }
 
 1;
-#ABSTRACT: Carp::Always, but show syntax-highlighted source code context
-
+# ABSTRACT: Carp::Always, but show syntax-highlighted source code context
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Carp::Always::SyntaxHighlightSource - Carp::Always, but show syntax-highlighted source code context
 
 =head1 VERSION
 
-version 0.02
+This document describes version 0.03 of Carp::Always::SyntaxHighlightSource (from Perl distribution Carp-Always-SyntaxHighlightSource), released on 2016-03-16.
 
 =head1 SYNOPSIS
 
@@ -76,6 +78,22 @@ Or, for less carpal tunnel syndrome:
 
 Modified from L<Carp::Source::Always>.
 
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/Carp-Always-SyntaxHighlightSource>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/sharyanto/perl-Carp-Always-SyntaxHighlightSource>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Carp-Always-SyntaxHighlightSource>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 SEE ALSO
 
 L<Carp::Always>
@@ -84,16 +102,17 @@ L<Carp::Source> and L<Carp::Source::Always>
 
 L<carpa>
 
+L<Devel::Confess>
+
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Steven Haryanto.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
