@@ -9,7 +9,7 @@ use Term::ANSIColor;
 #use Text::ANSI::Util qw(ta_strip);
 use Tie::Cache;
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 require Exporter;
 our @ISA       = qw(Exporter);
@@ -203,19 +203,21 @@ sub get_context {
 sub source_cluck ($;@) { warn longmess_heavy(@_) }
 
 1;
-#ABSTRACT: Die/warn of errors with stack backtrace and source context
-
+# ABSTRACT: Die/warn of errors with stack backtrace and source context
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Carp::SyntaxHighlightSource - Die/warn of errors with stack backtrace and source context
 
 =head1 VERSION
 
-version 0.02
+This document describes version 0.03 of Carp::SyntaxHighlightSource (from Perl distribution Carp-Always-SyntaxHighlightSource), released on 2016-03-16.
 
 =head1 SYNOPSIS
 
@@ -283,20 +285,35 @@ features are present. The code borrows heavily from C<Carp>.
 
 Modified from L<Carp::Source>.
 
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/Carp-Always-SyntaxHighlightSource>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/sharyanto/perl-Carp-Always-SyntaxHighlightSource>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Carp-Always-SyntaxHighlightSource>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 SEE ALSO
 
 L<Carp::Always::SyntaxHighlightSource>
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Steven Haryanto.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
